==> react-native-bugsee-5.4.1.tgz: package/src/appearance/index.js <==
import { NativeModules } from 'react-native';
import { hexColorToRgba, isNil } from '../common/utils';
import AndroidFeedbackAppearance from './feedback.android';
import IOSFeedbackAppearance from './feedback.ios';
import AndroidReportAppearance from './report.android';
import IOSReportAppearance from './report.ios';
const NativeBridge = NativeModules.Bugsee;
/**
 * Appearance settings for Bugsee UI
 */
export default class Appearance {
    props = new Map();
    androidReportAppearance = new AndroidReportAppearance(this.$get.bind(this), this.$set.bind(this));
    iosReportAppearance = new IOSReportAppearance(this.$get.bind(this), this.$set.bind(this));
    androidFeedbackAppearance = new AndroidFeedbackAppearance(this.$get.bind(this), this.$set.bind(this));
    iosFeedbackAppearance = new IOSFeedbackAppearance(this.$get.bind(this), this.$set.bind(this));
    $set(name, value) {
        this.props.set(name, value);
        const [r, g, b, a] = hexColorToRgba(value) || [];
        if (!isNil(r)) {
            NativeBridge.setAppearanceProperty({
                name,
                r,
                g,
                b,
                a,
            });
        }
    }
    $get(key) {
        // TODO: Add nativee data reading
        return this.props.get(key);
    }
    // private loadAppearanceData(data: Record<string, string>): void {
    //   this.props.clear();
    //   const keys = Object.keys(data);
    //   for (let i = 0; i < keys.length; ++i) {
    //     const key = keys[i];
    //     const value = data[key];
    //     if (!isNil(value)) {
    //       this.props.set(key, data[key]);
    //     }
    //   }
    // }
    /**
     * Appearance settings for Android report activity
     */
    get AndroidReportAppearance() {
        return this.androidReportAppearance;
    }
    /**
     * Appearance settings for Android report activity
     */
    get AndroidFeedbackAppearance() {
        return this.androidFeedbackAppearance;
    }
    /**
     * Appearance settings for iOS feedback controller
     */
    get IOSFeedbackAppearance() {
        return this.iosFeedbackAppearance;
    }
    /**
     * Appearance settings for iOS report controller
     */
    get IOSReportAppearance() {
        return this.iosReportAppearance;
    }
}

==> react-native-bugsee-5.5.2.tgz: package/src/appearance/index.js <==
import { hexColorToRgba, isNil } from '../common/utils';
import AndroidFeedbackAppearance from './feedback.android';
import IOSFeedbackAppearance from './feedback.ios';
import AndroidReportAppearance from './report.android';
import IOSReportAppearance from './report.ios';
import { getRNBugseeModule } from '../utils/bridge';
const NativeBridge = getRNBugseeModule();
/**
 * Appearance settings for Bugsee UI
 */
export default class Appearance {
    props = new Map();
    androidReportAppearance = new AndroidReportAppearance(this.$get.bind(this), this.$set.bind(this));
    iosReportAppearance = new IOSReportAppearance(this.$get.bind(this), this.$set.bind(this));
    androidFeedbackAppearance = new AndroidFeedbackAppearance(this.$get.bind(this), this.$set.bind(this));
    iosFeedbackAppearance = new IOSFeedbackAppearance(this.$get.bind(this), this.$set.bind(this));
    $set(name, value) {
        this.props.set(name, value);
        const [r, g, b, a] = hexColorToRgba(value) || [];
        if (!isNil(r)) {
            NativeBridge?.setAppearanceProperty({
                name,
                r,
                g,
                b,
                a,
            });
        }
    }
    $get(key) {
        // TODO: Add nativee data reading
        return this.props.get(key);
    }
    // private loadAppearanceData(data: Record<string, string>): void {
    //   this.props.clear();
    //   const keys = Object.keys(data);
    //   for (let i = 0; i < keys.length; ++i) {
    //     const key = keys[i];
    //     const value = data[key];
    //     if (!isNil(value)) {
    //       this.props.set(key, data[key]);
    //     }
    //   }
    // }
    /**
     * Appearance settings for Android report activity
     */
    get AndroidReportAppearance() {
        return this.androidReportAppearance;
    }
    /**
     * Appearance settings for Android report activity
     */
    get AndroidFeedbackAppearance() {
        return this.androidFeedbackAppearance;
    }
    /**
     * Appearance settings for iOS feedback controller
     */
    get IOSFeedbackAppearance() {
        return this.iosFeedbackAppearance;
    }
    /**
     * Appearance settings for iOS report controller
     */
    get IOSReportAppearance() {
        return this.iosReportAppearance;
    }
}
